@@ -122,14 +122,14 @@ a2d <- data
 a2d$rate <- ifelse(is.na(a2d$event), 0, a2d$event)
 a2d$exposure <- stats::rnorm(25, 50, 5)
 a2d$rate <- a2d$rate / a2d$exposure
-a2 <- shewhart(a2d, ts_event=c("Rate"="rate"))
+a2 <- cusum(a2d, ts_event=c("Rate"="rate"))
 test_that("ts_event parameter functions as expected", {
   expect_equal(a2$data$reference_time, range(a2d$time))
   expect_equal(a2$data$data[[1]], a2d$time)
   expect_equal(a2$data$data$rate, a2d$rate)
 })
 
-a2 <- shewhart(a2d, analysis_of="Testing")
+a2 <- cusum(a2d, analysis_of="Testing")
 test_that("ts_event parameter functions as expected", {
   expect_equal(a2$analysis_of, "Testing")
 })
@@ -164,7 +164,7 @@ test_that("delta parameter functions as expected", {
 
 a25 <- cusum(a2d, H=5)
 a215 <- cusum(a2d, H=1.5)
-test_that("delta parameter functions as expected", {
+test_that("H parameter functions as expected", {
   expect_is(a25, "mdsstat_test")
   expect_equal(a25$params$H, 5)
   expect_equal(a215$params$H, 1.5)
